.. role:: hidden
    :class: hidden-section

ax.storage
==========

.. automodule:: ax.storage
.. currentmodule:: ax.storage


JSON
----

ax.storage.json\_store.decoder module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.decoder
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.json\_store.decoders module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.decoders
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.json\_store.encoder module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.encoder
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.json\_store.encoders module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.encoders
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.json\_store.load module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.load
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.json\_store.registry module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.registry
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.json\_store.save module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.json_store.save
    :members:
    :undoc-members:
    :show-inheritance:


SQLAlchemy (MySQL / SQLite)
---------------------------
ax.storage.sqa\_store.base\_decoder module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. automodule:: ax.storage.sqa_store.decoder
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.base\_encoder module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.encoder
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.db module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.db
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: Base

ax.storage.sqa\_store.delete module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.delete
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.json module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.json
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.load module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.load
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.save module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.save
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.structs module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.structs
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.sqa\_classes module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.sqa_classes
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.sqa\_config module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.sqa_config
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

ax.storage.sqa\_store.sqa\_enum module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.sqa_enum
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.timestamp module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.timestamp
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.utils module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.utils
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.validation module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.validation
    :members:
    :undoc-members:
    :show-inheritance:

ax.storage.sqa\_store.reduced_state module
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.storage.sqa_store.reduced_state
    :members:
    :undoc-members:
    :show-inheritance:

Registries
----------

.. automodule:: ax.storage.botorch_modular_registry
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.storage.metric_registry
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.storage.runner_registry
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.storage.registry_bundle
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: ax.storage.transform_registry
    :members:
    :undoc-members:
    :show-inheritance:

Utilities
---------

.. automodule:: ax.storage.utils
    :members:
    :undoc-members:
    :show-inheritance:
